%define subrel 1
Summary:  Kernel Virtual Machine virtualization environment
Name:     kvm
Version:  74
Release:  %mkrel 7
License:  GPLv2+ and LGPLv2+
Group:    Emulators
Url:      http://kvm.qumranet.com/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
Source0:  %{name}-%{version}.tar.gz
Source1:  kvm
Source2:  README.urpmi
Patch0:   qemu-0.9.1-mdv-CVE-2008-5714.patch
Patch1:   qemu-0.9.1-rh-CVE-2008-2382.patch
BuildRequires:  dev86
BuildRequires:  iasl
BuildRequires:  zlib-devel
BuildRequires:  SDL-devel
BuildRequires:  texi2html

%description
KVM (for Kernel-based Virtual Machine) is a full virtualization solution for
Linux on x86 hardware containing virtualization extensions (Intel VT or
AMD-V). It consists of a loadable kernel module, kvm.ko, that provides the
core virtualization infrastructure and a processor specific module,
kvm-intel.ko or kvm-amd.ko.

Using KVM, one can run multiple virtual machines running unmodified Linux or
Windows images. Each virtual machine has private virtualized hardware: a
network card, disk, graphics adapter, etc.


%prep
%setup -q
%patch0 -p0 -b .cve-2008-5714
%patch1 -p0 -b .cve-2008-2382


%build
# we need to install the data bits in a different path
sed -i 's/datasuffix=\"\/share\/qemu\"/datasuffix=\"\/share\/kvm\"/' qemu/configure
./configure --prefix=%_prefix --arch=%_target_cpu --qemu-cflags="%{optflags}"
sed -i 's/gcc -m32/gcc/' bios/Makefile
%make libkvm user qemu bios vgabios extboot

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} WANT_MODULE="" install

# Add initscript
mkdir -p %{buildroot}%{_initrddir}
install -m 700 %{SOURCE1} %{buildroot}%{_initrddir}

mv %{buildroot}%{_mandir}/man1/qemu.1 %{buildroot}%{_mandir}/man1/kvm.1
chmod a-x %{buildroot}%{_mandir}/man1/kvm.1

rm -rf %{buildroot}%{_mandir}/man*/qemu-{img,nbd}*
rm -f %{buildroot}%{_bindir}/{qemu-img,qemu-nbd}
rm -rf %{buildroot}%{_docdir}/qemu

# no shared lib, static libs
rm -fr %{buildroot}%{_includedir} %{buildroot}%{_libdir}

# We're only build x86, so kill other BIOS to save disk space
rm -f %{buildroot}%{_datadir}/%{name}/{openbios-sparc*,ppc_rom.bin,video.x}

mv %{buildroot}%{_bindir}/qemu* %{buildroot}%{_bindir}/kvm

install -D user/{kvmctl,kvmtrace,kvmtrace_format} %{buildroot}%{_bindir}

mkdir -p %{buildroot}%{_sysconfdir}/udev/rules.d/
cat > %{buildroot}%{_sysconfdir}/udev/rules.d/65-kvm.rules << EOF
KERNEL=="kvm", NAME="%k", MODE="0660",OWNER="root",GROUP="kvm"
EOF

ln -s kvm %{buildroot}%{_bindir}/qemu-kvm

mkdir -p %{buildroot}%{_docdir}/%{name}
cp -pr qemu/qemu-*.html %{buildroot}%{_docdir}/%{name}
install -m 644 %{SOURCE2} %{buildroot}%{_docdir}/%{name}/README.urpmi

%clean
rm -rf %{buildroot}

%pre
%_pre_groupadd kvm

%postun
%_postun_groupdel kvm

%files
%defattr(-,root,root)
%{_docdir}/*
%{_bindir}/kvm
%{_bindir}/kvmctl
%{_bindir}/kvmtrace
%{_bindir}/kvmtrace_format
%{_bindir}/qemu-kvm
%dir %{_datadir}/kvm
%{_initrddir}/%{name}
%{_datadir}/kvm/*
/usr/share/man/man1/kvm.1.lzma
%_sysconfdir/udev/rules.d/65-kvm.rules




%changelog
* Mon Aug 10 2009 Vincent Guardiola <vguardiola@mandriva.com> 74-7.1mdv2009.0
+ Revision: 414306
-Add init script (#Bug 52687)

  + Bogdano Arendartchuk <bogdano@mandriva.com>
    - restrict access to /dev/kvm only to the kvm group

* Wed Jan 14 2009 Security Team <security@mandriva.com> 74-3.1mdv2009.0
+ Revision: 329295
- P1: fix for CVE-2008-5714
  P2: fix for CVE-2008-2382

  + root <root>
    - Branching 2009.0 release for updates.

* Sun Sep 28 2008 Pascal Terjan <pterjan@mandriva.org> 74-2mdv2009.0
+ Revision: 289047
- Add 65-kvm.rules back (#44349)

* Sat Sep 13 2008 Pascal Terjan <pterjan@mandriva.org> 74-1mdv2009.0
+ Revision: 284360
- BuildRequires zlib-devel and texi2html
- BuildRequires iasl
- import kvm


